# Introduction
This package connects to the stocksymbolsapi that I created and allows you to get list of stock symbols from all major stock exchanges over the world.

# How to use
You need to have an API key

# Useful links
- https://help.yahoo.com/kb/SLN2310.html


# Sponsor this project